clear

use ISSP1998.dta, clear


/* VARIABLE DEFINITIONS */

tab v217, gen(r)
sum v217 

rename r7 baptist 
rename r8 methodist 
rename r9 lutheran 
rename r10 presbytian  
rename r11 churchofirelandengland 
rename r12 congregational 
rename r14 unitarians 
rename r15 protfreechurch 
rename r16 prototherclass 
rename r22 unitedchurch 
rename r23 freepresbytian 
rename r24 brethren 
rename r25 pentecostal 
rename r26 mormon 
rename r27 salvationarmy 
rename r28 seventhday 
rename r30 Hussites
rename r34 nodem 
rename r35 otherchritian 


/* protestant broad  r7+r8+r9+r10+r11+r12+r14+r15+r16+r22+r23+r24+r25+r27+r28+r30+r34*/ 

gen catholicbroad = r1 + r2
gen protestantonly = baptist + methodist + lutheran + presbytian + churchofirelandengland + congregational + unitarian + protfreechurch + prototherclass + unitedchurch + freepresbytian + brethren + nodem + pentecostal + salvationarmy + seventhday + Hussites + otherchritian
replace catholicbroad = . if catholicbroad ==0replace catholicbroad = 0 if protestantonly ==1
codebook catholicbroad

codebook v3
tabulate v3, gen(m)

/* Work ethic */ 

codebook v213
sum v213, d

replace v213 = 0 if v213 == .
rename v213 workinghours

generate workinghoursofworking = workinghours if workinghours>=1
codebook workinghoursofworking

gen positivehours = 0 
replace positivehours = 1 if workinghoursofworking!=.
codebook positivehours
codebook workinghours


/* Social ethic */ 

/* Religious practice index */ 
codebook v218
codebook v58
codebook v59
codebook v60
/*recode variable v60 to increase with religiousity*/
recode v60 1=7 2=6 3=5 4=4 5=3 6=2 7=1, gen(v60recode)
codebook v60recode

pca v58 v59 v60recode v218
predict religiouspracticeindex, score
codebook religiouspracticeindex

/* Rule of law */ 

/* Trust institutions index */ 
codebook v23
recode v20 1=5 2=4 3=3 4=2 5=1, gen(v23recode)
codebook v20
recode v20 1=5 2=4 3=3 4=2 5=1, gen(v20recode)
pca v20recode v23recode
predict trustistitutionsindex, score
codebook trustistitutionsindex


/* Homogenous values */

/* Importance of family index */
sum v7 v8
gen importanceoffamily= v7-v8
codebook importanceoffamily

/* Independent variables */

tab v53, gen(rr)

gen protestantraisedbroad = rr6+rr7+rr8+rr9+rr10+rr11+rr12+rr13+rr14+rr20+rr21+rr22+rr23+rr25+rr26+rr28+rr31+rr32
replace rr1 = 10 if rr1==1
replace rr2 = 13 if rr2==1


gen religionraisedbroad = rr1+ protestantraisedbroad +rr2
replace religionraisedbroad = . if religionraisedbroad ==0replace religionraisedbroad = 0 if protestantraisedbroad ==1
codebook religionraisedbroad


/* Faith index */ 
codebook v39
recode v39 1=4 2=3 3=2 4=1, gen(v39recode)

codebook v40 
recode v40 1=4 2=3 3=2 4=1, gen(v40recode)

codebook v41
recode v41 1=4 2=3 3=2 4=1, gen(v41recode)

codebook v39recode
drop if v39recode==.
codebook v40recode
drop if v40recode==.
codebook v41recode
drop if v41recode==.


pca v39recode v40recode v41recode 
predict faithindex, score
sum faithindex
codebook faithindex


/* Upbringing and education */
sum v57 v205
codebook v57
codebook v205

/* Control variables */ 
sum v200 v201 v202 
rename v200 gender
rename v201 age

codebook age
gen age2 = age^2
codebook age2

codebook v202
drop if v202==.
tabulate v202, gen(status)
sum status3
codebook status3
sum status4
codebook status4 
gen divorcedandseperated = status3 + status4
rename status2 widowed 
rename status5 single  

rename v57 religiousupbringing

codebook religiousupbringing
replace religiousupbringing = 1 if religiousupbringing==.


rename v205 education
codebook education


codebook gender
gen sex = 0 
replace sex = 1 if gender==2

rename m1 Australia
rename m2 WestGermany 	
rename m3 EastGermany 
gen Germany = WestGermany + EastGermany
rename m4 GB 	
rename m5 NI
rename m6 USA	
rename m7 Austria 	
rename m8 Hungry 	
rename m9 Italy 	
rename m10 Ireland 	
rename m11 Netherlands 	
rename m12 Norway 	
rename m13 Sweden
rename m14 Czech 
rename m15 Solvenia 	
rename m16 Poland 
rename m18 Russia
rename m19 NewZealand
rename m21 Philippines
rename m22 Isreal
rename m23 Japan
rename m24 Spain 
rename m25 Latvia 
rename m26 Solvakia
rename m27 France	
rename m28 Cyprus
rename m29 Portugal 
rename m30 Chile	
rename m31 Denmark
rename m32 Switzerland 	


egen Trustistitutionsindex = std(trustistitutionsindex) if catholicbroad!=.
sum Trustistitutionsindex

egen Religiouspracticeindex = std(religiouspracticeindex) if catholicbroad!=.
sum Religiouspracticeindex

egen Faithindex = std(faithindex) if catholicbroad!=.
codebook Faithindex

egen Age = std(age) if catholicbroad!=.
codebook Age
drop if Age==.
egen Age2 = std(age2) if catholicbroad!=.
codebook Age2

egen Religiousupbringing = std(religiousupbringing) if catholicbroad!=.
codebook Religiousupbringing
sum Religiousupbringing

egen Education = std(education) if catholicbroad!=.
codebook Education
sum Education
drop if Education==.


/* Interaction terms*/

gen catholicfaith = catholicbroad * Faithindex

gen catholicRupbring = religionraisedbroad * Religiousupbringing

gen catholicEducation = catholicbroad * Education




/* REGRESSION ANALYSIS */


/* Regression analysis for panels (a) */ 

/* Model 11 */ 

probit positivehours catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholicEducation sex Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad !=.,robust
outreg2 using resultsdatapositivehours, tdec(2) replace
predict model1
sum model1 if catholicbroad == 1
sum model1 if catholicbroad == 0
sdtest model1, by (catholicbroad)
robvar model1, by (catholicbroad)

/* Model 12 */ 

reg workinghoursofworking catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholicEducation sex Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad !=.,robust
outreg2 using resultsworking, tdec(2) append
predict model2, residuals
sdtest model2, by (catholicbroad)
robvar model2, by (catholicbroad)

/* Model 13 */ 

reg Religiouspracticeindex catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholicEducation sex Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad !=.,robust
outreg2 using resultsreligious, tdec(2) append
predict model4, residuals
sdtest model4, by (catholicbroad)
robvar model4, by (catholicbroad)

/* Model 14 */ 

reg Trustistitutionsindex catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholicEducation sex Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad !=.,robust
outreg2 using resultstrust, tdec(2) append
predict model5, residuals
sdtest model5, by (catholicbroad)
robvar model5, by (catholicbroad)

/* Model 15 */ 

oprobit importanceoffamily catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholicEducation sex Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad !=.,robust
outreg2 using resultsdataimportance, tdec(2) replace 
predict model6
sdtest model6, by (catholicbroad)
robvar model6, by (catholicbroad)


/* Differences between Protestant and Catholic for panels (b) */ 

probit positivehours catholicbroad sex age age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

reg workinghoursofworking catholicbroad sex age age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

reg Religiouspracticeindex catholicbroad sex age age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

reg Trustistitutionsindex catholicbroad sex age age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

oprobit importanceoffamily catholicbroad sex age age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland  Russia NewZealand  Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append



