clear

use ISSP2008.dta, clear


/* VARIABLE DEFINITIONS */


codebook V4
tab V5
tabulate V4, gen(m)

tabulate RELIG, gen(r)

gen catholicbroad = r2+r3
gen protestantbroad = r6+r7+r10+r11+r12+r19+r5+r34+r27+r4+r31+r32+r33+r35+r20+r28+r51+r44
replace catholicbroad = . if catholicbroad ==0replace catholicbroad = 0 if protestantbroad ==1


/* Work ethic */ 
codebook WRKHRS
sum WRKHRS
gen workingmissequalzero = WRKHRS
replace workingmissequalzero = 0 if workingmissequalzero ==.a
replace workingmissequalzero = 0 if workingmissequalzero ==.n
rename workingmissequalzero workinghours
gen positivehours = 0 
replace positivehours = 1 if workinghours>=1
generate workinghoursofworking = workinghours if workinghours>=1


/* Social ethic */ 

/* Religious practice index */ 
codebook V59
codebook V60 
codebook V63
/* recode variable V63 to increase with religiousity */
recode V63 1=7 2=6 3=5 4=4 5=3 6=2 7=1, gen(V63recode)
codebook ATTEND
pca V59 V60 V63recode ATTEND
predict religiouspracticeindex, score
codebook religiouspracticeindex

/* Rule of law */ 

/* Trust institutions index */ 
codebook V14
recode V14 1=5 2=4 3=3 4=2 5=1, gen(V14recode)
codebook V17
recode V17 1=5 2=4 3=3 4=2 5=1, gen(V17recode)

pca V14recode V17recode
predict trustistitutionsindex, score
codebook trustistitutionsindex

/* Homogenous values */

/* Importance of family index */
codebook V7
codebook V8
gen importanceoffamily= V7-V8
codebook importanceoffamily

/* Independent variables*/
/* Religious denomination */
sum RELIGGRP
tab RELIGGRP

/* CatholicR */
codebook V52
tab V52, gen(rr)   

gen protestantraisedbroad = rr6+rr7+rr11+rr10+rr12+rr18+rr5+rr32+rr25+rr4+rr33+rr31+rr19+rr26+rr28+rr29+rr30+rr49+rr39

gen religionraisedbroad = rr1+ protestantraisedbroad +rr2
replace religionraisedbroad = . if religionraisedbroad ==0replace religionraisedbroad = 0 if protestantraisedbroad ==1
codebook religionraisedbroad

/* Faith index*/ 

codebook V35
recode V35 1=4 2=3 3=2 4=1, gen(V35recode)

codebook V36
recode V36 1=4 2=3 3=2 4=1, gen(V36recode)

codebook V37
recode V37 1=4 2=3 3=2 4=1, gen(V37recode)

pca V35recode V36recode V37recode 
predict faithindex, score
codebook faithindex
drop if faithindex==.

/* Upbringing and education */
sum V58 DEGREE

/* Control variables */ 
sum SEX AGE  
codebook SEX
drop if SEX==.
rename SEX women 
codebook AGE
drop if AGE==.
gen AGE2 = AGE^2


tabulate MARITAL, gen(status)
codebook status3
sum status4
codebook status4 
drop if status3==.
drop if status4==.
gen divorcedandseperated = status3 + status4
drop if status2==.
rename status2 widowed 
drop if status5==.
rename status5 single  
codebook widowed

codebook V58 
drop if V58==.c
drop if V58==.n
codebook V58 
rename V58 religiousupbringing


codebook DEGREE
drop if DEGREE==.d
drop if DEGREE==.n
codebook DEGREE
rename DEGREE education 


rename m1 Australia
rename m2 Austria 
rename m4 Chile	
rename m7 Cyprus
rename m8 Czech 
rename m9 Denmark
rename m12 France
rename m13 WestGermany 	
rename m14 EastGermany 
gen Germany = WestGermany + EastGermany
rename m15 Hungry 	
rename m16 Ireland 
gen Isreal = m17 + m18
gen Italy = m19 + m20
rename m21 Japan
rename m23 Latvia 
rename m25 Netherlands 
rename m26 NewZealand
rename m27 Norway 
rename m28 Philippines
rename m29 Poland 
rename m30 Portugal 
rename m31 Russia
rename m32 Solvakia
rename m33 Solvenia
rename m35 Spain 
rename m36 Sweden
rename m37 Switzerland 
rename m40 GB 	
rename m41 NI
rename m42 USA


/* Standardise variables */ 

egen Trustistitutionsindex = std(trustistitutionsindex) if catholicbroad!=.
sum Trustistitutionsindex

egen Religiouspracticeindex = std(religiouspracticeindex) if catholicbroad!=.
sum Religiouspracticeindex
codebook Religiouspracticeindex

egen Faithindex = std(faithindex) if catholicbroad!=.
codebook Faithindex

egen Age = std(AGE) if catholicbroad!=.
codebook Age
egen Age2 = std(AGE2) if catholicbroad!=.
codebook Age2

egen Religiousupbringing = std(religiousupbringing) if catholicbroad!=.
codebook Religiousupbringing
sum Religiousupbringing

egen Education = std(education) if catholicbroad!=.
codebook Education 
sum Education


/* protestantbroad = r6+r10+r11+r19+r5+r34+r27+r4+r35+r17+r28+r51+r44 */


/* Interaction terms */ 

gen catholicfaith = catholicbroad * Faithindex

gen catholiceducation = catholicbroad * Education
gen catholicRupbring = religionraisedbroad * Religiousupbringing



/* REGRESSION ANALYSIS */


/* Regression analysis for panels (a) */ 

/* Model 11 */ 

probit positivehours catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad !=.,robust
outreg2 using probit200ghjk8ss, tdec(2) append
predict num7
sum num7 if catholicbroad == 1
sum num7 if catholicbroad == 0
sdtest num7, by (catholicbroad)
robvar num7, by (catholicbroad)

/* Model 12 */ 

reg workinghoursofworking catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust
outreg2 using reg2008fgtfy, tdec(2) append
predict num8, residuals
sdtest num8, by (catholicbroad)
robvar num8, by (catholicbroad)

/* Model 13 */ 
reg Religiouspracticeindex catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust
outreg2 using reg20dfk088ghjk, tdec(2) append 
predict num10, residuals
sdtest num10, by (catholicbroad)
robvar num10, by (catholicbroad)

/* Model 14 */ 

reg Trustistitutionsindex catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust
outreg2 using reg2008fghey, tdec(2) append 
predict num11, residuals
sdtest num11, by (catholicbroad)
robvar num11, by (catholicbroad)

/* Model 15 */ 

oprobit importanceoffamily catholicbroad Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust
outreg2 using oprobit2008dhdy6, tdec(2) append 
predict num12
sdtest num12, by (catholicbroad)
robvar num12, by (catholicbroad)


/* Differences between Protestant and Catholic for panels (b) */ 

probit positivehours catholicbroad women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) replace

reg workinghoursofworking catholicbroad women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

reg Religiouspracticeindex catholicbroad women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

reg Trustistitutionsindex catholicbroad women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

oprobit importanceoffamily catholicbroad women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if catholicbroad!=., robust 
outreg2 using resultstable, tdec(2) append

