clear

use ISSP2008.dta, clear


/* VARIABLE DEFINITIONS */

codebook V4
tab V5
tabulate V4, gen(m)


tabulate RELIG, gen(r)

gen protfreechurch = r27 if m9!=1 & m27!=1
codebook protfreechurch

gen protestant = r4 if m15==1
codebook protestant
gen prot2 = r4 if m25==1
codebook prot2
gen prot3 = r4 if m32==1
codebook prot3
gen prot4 = r4 if m37==1
codebook prot4
replace protestant = 1 if prot2==1
replace protestant = 0 if protestant ==.
replace protestant = 1 if prot3==1
replace protestant = 0 if protestant ==.
replace protestant = 1 if prot4==1
replace protestant = 0 if protestant ==.
codebook protestant

gen unitedchurch = r35 if m23!=1
codebook unitedchurch
codebook r7
codebook r19
codebook r20

gen protestants = r7+r19+r20+protfreechurch+protestant+unitedchurch
codebook protestants

gen strictcalvinism = r2 +r3 
gen protestantonly = r7+r19+r20+protfreechurch+protestant+unitedchurch
replace strictcalvinism = . if strictcalvinism ==0replace strictcalvinism = 0 if protestantonly ==1

/* Work ethic */ 
codebook WRKHRS
sum WRKHRS
gen workingmissequalzero = WRKHRS
replace workingmissequalzero = 0 if workingmissequalzero ==.a
replace workingmissequalzero = 0 if workingmissequalzero ==.n
rename workingmissequalzero workinghours
gen positivehours = 0 
replace positivehours = 1 if workinghours>=1
generate workinghoursofworking = workinghours if workinghours>=1

/* Social ethic */ 

/* Religious practice index */ 
codebook V59
codebook V60 
codebook V63

/* recode variable V63 to increase with religiousity */
recode V63 1=7 2=6 3=5 4=4 5=3 6=2 7=1, gen(V63recode)
codebook ATTEND
pca V59 V60 V63recode ATTEND
predict religiouspracticeindex, score
codebook religiouspracticeindex

/* Rule of law */ 

/*Trust institutions index */ 
codebook V14
recode V14 1=5 2=4 3=3 4=2 5=1, gen(V14recode)
codebook V17
recode V17 1=5 2=4 3=3 4=2 5=1, gen(V17recode)

pca V14recode V17recode
predict trustistitutionsindex, score
codebook trustistitutionsindex

/* Homogenous values */

/*Importance of family index */
codebook V7
codebook V8
gen importanceoffamily= V7-V8
codebook importanceoffamily

/*Independent variables */

/* Religious denomination */
sum RELIGGRP
tab RELIGGRP

/* CatholicR */
codebook V52
tab V52, gen(rr) 

gen protfreechurch2 = rr27 if m9!=1 & m27!=1

gen protestant2 = rr4 if m15==1
codebook protestant2
gen prot22 = protestant2 if m25==1
codebook prot22
gen prot33 = protestant2 if m32==1
codebook prot33
gen prot44 = protestant2 if m37==1
codebook prot44
replace protestant2 = 1 if prot22==1
replace protestant2 = 0 if protestant2 ==.
replace protestant2 = 1 if prot33==1
replace protestant2 = 0 if protestant2 ==.
replace protestant2 = 1 if prot44==1
replace protestant2 = 0 if protestant2 ==.
codebook protestant2


gen unitedchurch2 = rr35 if m23!=1 

gen protestantraisedstrictcalvinism = rr7+rr18+rr19+protestant2+protfreechurch2+unitedchurch2


gen religionraisedstrictcalvinism = rr2+ protestantraisedstrictcalvinism +rr3
replace religionraisedstrictcalvinism = . if religionraisedstrictcalvinism ==0replace religionraisedstrictcalvinism = 0 if protestantraisedstrictcalvinism ==1
codebook religionraisedstrictcalvinism


/* Faith index */ 

codebook V35
recode V35 1=4 2=3 3=2 4=1, gen(V35recode)

codebook V36
recode V36 1=4 2=3 3=2 4=1, gen(V36recode)

codebook V37
recode V37 1=4 2=3 3=2 4=1, gen(V37recode)

pca V35recode V36recode V37recode 
predict faithindex, score
codebook faithindex
drop if faithindex==.

/* Upbringing and education */
sum V58 DEGREE

/* Control variables */ 
sum SEX AGE  
codebook SEX
drop if SEX==.n
rename SEX women 
codebook AGE
drop if AGE==.n
gen AGE2 = AGE^2


tabulate MARITAL, gen(status)
codebook status3
sum status4
codebook status4 
drop if status3==.
drop if status4==.
gen divorcedandseperated = status3 + status4
drop if status2==.
rename status2 widowed 
drop if status5==.
rename status5 single  
codebook widowed

codebook V58 
drop if V58==.c
drop if V58==.n
codebook V58 
rename V58 religiousupbringing


codebook DEGREE
drop if DEGREE==.d
drop if DEGREE==.n
codebook DEGREE
rename DEGREE education 


rename m1 Australia
rename m2 Austria 
rename m4 Chile	
rename m7 Cyprus
rename m8 Czech 
rename m9 Denmark
rename m12 France
rename m13 WestGermany 	
rename m14 EastGermany 
gen Germany = WestGermany + EastGermany	
rename m15 Hungry 	
rename m16 Ireland 
gen Isreal = m17 + m18
gen Italy = m19 + m20
rename m21 Japan
rename m23 Latvia 
rename m25 Netherlands 
rename m26 NewZealand
rename m27 Norway 
rename m28 Philippines
rename m29 Poland 
rename m30 Portugal 
rename m31 Russia
rename m32 Solvakia
rename m33 Solvenia
rename m35 Spain 
rename m36 Sweden
rename m37 Switzerland 
rename m40 GB 	
rename m41 NI
rename m42 USA


/* Standardise variables */ 

egen Trustistitutionsindex = std(trustistitutionsindex) if strictcalvinism!=.
sum Trustistitutionsindex

egen Religiouspracticeindex = std(religiouspracticeindex) if strictcalvinism!=.
sum Religiouspracticeindex
codebook Religiouspracticeindex

egen Faithindex = std(faithindex) if strictcalvinism!=.
codebook Faithindex

egen Age = std(AGE) if strictcalvinism!=.
codebook Age
egen Age2 = std(AGE2) if strictcalvinism!=.
codebook Age2

egen Religiousupbringing = std(religiousupbringing)if strictcalvinism!=.
codebook Religiousupbringing
sum Religiousupbringing

egen Education = std(education) if strictcalvinism!=.
codebook Education 
sum Education


/* Interaction terms */ 

gen catholicfaith = strictcalvinism * Faithindex

gen catholiceducation = strictcalvinism * Education

gen catholicRupbring = religionraisedstrictcalvinism * Religiousupbringing




/* REGRESSION ANALYSIS */


/* Regression analysis for panels (a) */ 

/* Model 6 */ 

probit positivehours strictcalvinism Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism !=.,robust
outreg2 using probithours, tdec(2) replace
predict model1
sum model1 if strictcalvinism == 1
sum model1 if strictcalvinism == 0
sdtest model1, by (strictcalvinism)
robvar model1, by (strictcalvinism)

/* Model 7 */ 

reg workinghoursofworking strictcalvinism Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust
outreg2 using regworking, tdec(2) append
predict model2, residuals
sdtest model2, by (strictcalvinism)
robvar model2, by (strictcalvinism)

/* Model 8 */ 

reg Religiouspracticeindex strictcalvinism Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust
outreg2 using regreligiousindex, tdec(2) append 
predict model4, residuals
sdtest model4, by (strictcalvinism)
robvar model4, by (strictcalvinism)

/* Model 9 */ 

reg Trustistitutionsindex strictcalvinism Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust
outreg2 using regtrustindex, tdec(2) append 
predict model5, residuals
sdtest model5, by (strictcalvinism)
robvar model5, by (strictcalvinism)

/* Model 10 */ 

oprobit importanceoffamily strictcalvinism Faithindex Religiousupbringing Education catholicfaith catholicRupbring catholiceducation women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust
outreg2 using oprobitfamily, tdec(2) append 
predict model6
sdtest model6, by (strictcalvinism)
robvar model6, by (strictcalvinism)


/* Differences between Protestant and Catholic for panels (b) */ 

probit positivehours strictcalvinism women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust 
outreg2 using resultstab, tdec(2) append

reg workinghoursofworking strictcalvinism women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust 
outreg2 using resultstab, tdec(2) append

reg Religiouspracticeindex strictcalvinism women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust 
outreg2 using resultstab, tdec(2) append

reg Trustistitutionsindex strictcalvinism women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust 
outreg2 using resultstab, tdec(2) append

oprobit importanceoffamily strictcalvinism women Age Age2 widowed divorcedandseperated single Australia Germany GB NI USA Austria Hungry Italy Ireland Netherlands Norway Sweden Czech Solvenia Poland Russia NewZealand Philippines Isreal Japan Spain Latvia Solvakia France Cyprus Portugal Chile Denmark Switzerland if strictcalvinism!=., robust 
outreg2 using resultstab, tdec(2) append


